OpaqueReason

Enum OpaqueReason 

#[non_exhaustive]
pub enum OpaqueReason { InvalidUtf8, OddLengthUtf16, InvalidUtf16, }
Why a byte stream was kept opaque instead of being decoded as text.

#[non_exhaustive]: more failure reasons may be added in future releases, so match with a wildcard arm.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidUtf8

The bytes were not valid UTF-8.



OddLengthUtf16

A UTF-16 stream had an odd number of bytes, so it could not be split into 16-bit units.



InvalidUtf16

The 16-bit units did not form valid UTF-16 (for example an unpaired surrogate).