#[non_exhaustive]pub enum TextEncoding {
Utf8,
Utf8Bom,
Utf16Le,
Utf16Be,
OpaqueBytes,
}Expand description
A text encoding that DecodedText can recognize and round-trip.
#[non_exhaustive]: more encodings may be added in future releases, so match with a wildcard
arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Utf8
UTF-8 with no byte-order mark.
Utf8Bom
UTF-8 prefixed with a byte-order mark, which is preserved on re-encoding.
Utf16Le
Little-endian UTF-16 (identified by its byte-order mark).
Utf16Be
Big-endian UTF-16 (identified by its byte-order mark).
OpaqueBytes
Bytes that could not be decoded as text and are passed through verbatim.